@@ -56,9 +56,17 @@ OPTIONAL
 
 Your paste title description.
 
+=head1 SEE ALSO
+
+L<https://metacpan.org/pod/WWW::Pastebin::PastebinCom::Create"
+L< https://metacpan.org/pod/App::Nopaste"
+
+
 =head1 AUTHOR
+
 mfzz, <mfzz@cpan.org>
 
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2016 by mfzz.
